@@ -150,7 +150,7 @@ oldUseNetServer hosts = propertyList "olduse.net server" $ props
 		`requires` Ssh.userKeyAt (Just keyfile)
 			(User "root")
 			(Context "olduse.net")
-			(SshRsa, "ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD0F6L76SChMCIGmeyGhlFMUTgZ3BoTbATiOSs0A7KXQoI1LTE5ZtDzzUkrQRJVpJ640pfMR7cQZyBm8tv+kYIPp0238GrX43c1vgm0L78agDnBU7r2iNMyWIwhssK8O3ZAhp8Q4KCz1r8hP2nIiD0y1D1VWW8h4KWOS7I1XCEAjOTvFvEjTh6a9MyHrcIkv7teUUzTBRjNrsyijCFRk1+pEET54RueoOmEjQcWd/sK1tYRiMZjegRLBOus2wUWsUOvznJ2iniLONUTGAWRnEV+O7hLN6CD44osJ+wkZk8bPAumTS0zcSLckX1jpdHJicmAyeniWSd4FCqm1YE6/xDD")
+			(SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIGtHhNuO/abNTrc5pyWkwXz/F8FAHw8VcET0Yh4mjgOk root@kite")
 		`requires` Ssh.knownHost hosts "usw-s002.rsync.net" (User "root")
 	borgrepo = rsyncNetBorgRepo "olduse.net.borg" [Borg.UseSshKey keyfile]
 	keyfile = "/root/.ssh/olduse.net.key"
@@ -198,7 +198,7 @@ gitServer hosts = propertyList "git.kitenet.net setup" $ props
 		`requires` Ssh.userKeyAt (Just sshkey)
 			(User "root")
 			(Context "git.kitenet.net")
-			(SshRsa, "ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDLwUUkpkI9c2Wcnv/E4v9bJ7WcpiNkToltXfzRDd1F31AYrucfSMgzu3rtDpEL+wSnQLua/taJkWUWT/pyXOAh+90K6O/YeBZmY5CK01rYDz3kSTAtwHkMqednsRjdQS6NNJsuWc1reO8a4pKtsToJ3G9VAKufCkt2b8Nhqz0yLvLYwwU/mdI8DmfX6IgXhdy9njVEG/jsQnLFXY6QEfwKbIPs9O6qo4iFJg3defXX+zVMLsh3NE1P2i2VxMjxJEQdPdy9Z1sVpkiQM+mgJuylQQ5flPK8sxhO9r4uoK/JROkjPJNYoJMlsN+QlK04ABb7JV2JwhAL/Y8ypjQ13JdT")
+			(SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIOvgBVYP6srImGbJ+kg1K68HeUQqxHEBQswMWSqu9WOu root@kite")
 		`requires` Ssh.knownHost hosts "usw-s002.rsync.net" (User "root")
 	& Ssh.authorizedKeys (User "family") (Context "git.kitenet.net")
 	& User.accountFor (User "family")
@@ -936,7 +936,7 @@ house user hosts ctx sshkey = propertyList "home automation" $ props
 			user (userGroup user)
 		`requires` File.dirExists (takeDirectory sshkeyfile)
 		`requires` Ssh.knownHost hosts "kitenet.net" user
-	&  File.hasPrivContentExposed "/etc/darksky-forecast-url" anyContext
+	& File.hasPrivContentExposed "/etc/darksky-forecast-url" anyContext
   where
 	d = "/home/joey/house"
 	sshkeyfile = d </> ".ssh/key"
@@ -1238,53 +1238,42 @@ homeNAS = propertyList "home NAS" $ props
 		[ "# let users power control startech hub with uhubctl"
 		, "ATTR{idVendor}==\"" ++ hubvendor ++ "\", ATTR{idProduct}==\"005a\", MODE=\"0666\""
 		]
-	& autoMountDrive "archive-10" (USBHubPort hubvendor 1) (Just "archive-oldest")
-	& autoMountDrive "archive-11" (USBHubPort hubvendor 2) (Just "archive-older")
-	& autoMountDrive "archive-12" (USBHubPort hubvendor 3) (Just "archive-old")
-	& autoMountDrive "archive-13" (USBHubPort hubvendor 4) (Just "archive")
+	& autoMountDrivePort "archive-10" (USBHubPort hubvendor hubloc 1)
+		(Just "archive-oldest")
+	& autoMountDrivePort "archive-11" (USBHubPort hubvendor hubloc 2)
+		(Just "archive-older")
+	& autoMountDrivePort "archive-12" (USBHubPort hubvendor hubloc 3)
+		(Just "archive-old")
+	& autoMountDrivePort "archive-13" (USBHubPort hubvendor hubloc 4)
+		(Just "archive")
+	& autoMountDrive "passport" Nothing
 	& Apt.installed ["git-annex", "borgbackup"]
   where
 	hubvendor = "0409"
+	hubloc = "4-1.6"
 
-data USBHubPort = USBHubPort String Int
+data USBHubPort = USBHubPort
+	{ hubVendor :: String
+	, hubLocation :: String
+	, hubPort :: Int
+	}
 
 -- Makes a USB drive with the given label automount, and unmount after idle
 -- for a while.
 --
 -- The hub port is turned on and off automatically as needed, using
 -- uhubctl.
-autoMountDrive :: Mount.Label -> USBHubPort -> Maybe FilePath -> Property DebianLike
-autoMountDrive label (USBHubPort hubvendor port) malias = propertyList desc $ props
-	& File.ownerGroup mountpoint (User "joey") (Group "joey")
-		`requires` File.dirExists mountpoint
-	& case malias of
-		Just t -> ("/media/joey/" ++ t) `File.isSymlinkedTo`
-			File.LinkTarget mountpoint
-		Nothing -> doNothing <!> doNothing
-	& File.hasContent ("/etc/systemd/system/" ++ mount)
-		[ "[Unit]"
-		, "Description=" ++ label
-		, "Requires=" ++ hub
-		, "After=" ++ hub
-		, "[Mount]"
-		-- avoid mounting whenever the block device is available,
-		-- only want to automount on demand
-		, "Options=noauto"
-		, "What=" ++ devfile
-		, "Where=" ++ mountpoint
-		, "[Install]"
-		, "WantedBy="
-		]
-		`onChange` Systemd.daemonReloaded
+autoMountDrivePort :: Mount.Label -> USBHubPort -> Maybe FilePath -> Property DebianLike
+autoMountDrivePort label hp malias = propertyList desc $ props
 	& File.hasContent ("/etc/systemd/system/" ++ hub)
 		[ "[Unit]"
-		, "Description=Startech usb hub port " ++ show port
+		, "Description=Startech usb hub port " ++ show (hubPort hp)
 		, "PartOf=" ++ mount
 		, "[Service]"
 		, "Type=oneshot"
 		, "RemainAfterExit=true"
-		, "ExecStart=/usr/sbin/uhubctl -a on -p " ++ show port ++ " --vendor " ++ hubvendor 
-		, "ExecStop=/bin/sh -c 'uhubctl -a off -p " ++ show port ++ " --vendor " ++ hubvendor
+		, "ExecStart=/usr/sbin/uhubctl -a on " ++ selecthubport
+		, "ExecStop=/bin/sh -c 'uhubctl -a off " ++ selecthubport
 			-- Powering off the port does not remove device
 			-- files, so ask udev to remove the devfile; it will
 			-- be added back after the drive next spins up
@@ -1297,6 +1286,50 @@ autoMountDrive label (USBHubPort hubvendor port) malias = propertyList desc $ pr
 		, "WantedBy="
 		]
 		`onChange` Systemd.daemonReloaded
+	& autoMountDrive' 
+		[ "Requires=" ++ hub
+		, "After=" ++ hub
+		] label malias
+  where
+	devfile = "/dev/disk/by-label/" ++ label
+	mountpoint = "/media/joey/" ++ label
+	desc = "auto mount with hub port power control " ++ mountpoint
+	hub = "startech-hub-port-" ++ show (hubPort hp) ++ ".service"
+	mount = svcbase ++ ".mount"
+	svcbase = Systemd.escapePath mountpoint
+	selecthubport = unwords
+		[ "-p", show (hubPort hp)
+		, "-n", hubVendor hp
+		, "-l", hubLocation hp
+		]
+
+-- Makes a USB drive with the given label automount, and unmount after idle
+-- for a while.
+autoMountDrive :: Mount.Label -> Maybe FilePath -> Property DebianLike
+autoMountDrive = autoMountDrive' []
+
+autoMountDrive' :: [String] -> Mount.Label -> Maybe FilePath -> Property DebianLike
+autoMountDrive' mountunitadd label malias = propertyList desc $ props
+	& File.ownerGroup mountpoint (User "joey") (Group "joey")
+		`requires` File.dirExists mountpoint
+	& case malias of
+		Just t -> ("/media/joey/" ++ t) `File.isSymlinkedTo`
+			File.LinkTarget mountpoint
+		Nothing -> doNothing <!> doNothing
+	& File.hasContent ("/etc/systemd/system/" ++ mount)
+		([ "[Unit]"
+		, "Description=" ++ label
+		] ++ mountunitadd ++
+		[ "[Mount]"
+		-- avoid mounting whenever the block device is available,
+		-- only want to automount on demand
+		, "Options=noauto"
+		, "What=" ++ devfile
+		, "Where=" ++ mountpoint
+		, "[Install]"
+		, "WantedBy="
+		])
+		`onChange` Systemd.daemonReloaded
 	& File.hasContent ("/etc/systemd/system/" ++ automount)
 		[ "[Unit]"
 		, "Description=Automount " ++ label
@@ -1316,7 +1349,6 @@ autoMountDrive label (USBHubPort hubvendor port) malias = propertyList desc $ pr
 	devfile = "/dev/disk/by-label/" ++ label
 	mountpoint = "/media/joey/" ++ label
 	desc = "auto mount " ++ mountpoint
-	hub = "startech-hub-port-" ++ show port ++ ".service"
 	automount = svcbase ++ ".automount"
 	mount = svcbase ++ ".mount"
 	svcbase = Systemd.escapePath mountpoint
